@@ -13,7 +13,6 @@ int do_mounts(int argc, char *argv[]);
 int mount_nfs_root(int argc, char *argv[], int flags);
 int ramdisk_load(int argc, char *argv[], dev_t root_dev);
 void md_run(int argc, char *argv[]);
-int do_resume(int argc, char *argv[]);
 const char *bdevname(dev_t dev);
 
 extern int mnt_procfs;
@@ -60,4 +59,14 @@ ssize_t freadfile(FILE *f, char **pptr);
 #define DEBUG(x) do { } while (0)
 #endif
 
+#ifdef INI_DEBUG
+void dump_args(int argc, char *argv[]);
+#else
+static inline void dump_args(int argc, char *argv[])
+{
+	(void)argc;
+	(void)argv;
+}
+#endif
+
 #endif				/* KINIT_H */
